@@ -46,6 +46,7 @@ class CongestionSeries(KplerClient):
         vessel_operation: Optional[Enum] = None,
         waiting_duration_min: Optional[int] = None,
         waiting_duration_max: Optional[int] = None,
+        with_freight_view: bool = False,
     ):
 
         """
@@ -67,6 +68,7 @@ class CongestionSeries(KplerClient):
             vessel_operation: Optional[Enum] ``CongestionSeriesOperation``
             waiting_duration_min: Optional[int] Minimum waiting duration of vessel. Default to 0 days if not specified.
             waiting_duration_max: Optional[int] Maximum waiting duration of vessel. Default to 1000000 days if not specified.
+            with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
 
         Examples:
             >>> from datetime import date
@@ -110,5 +112,6 @@ class CongestionSeries(KplerClient):
             "vesselOperation": process_enum_parameter(vessel_operation, False),
             "waitingDurationMin": waiting_duration_min,
             "waitingDurationMax": waiting_duration_max,
+            "withFreightView": process_bool_parameter(with_freight_view),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
