@@ -8,6 +8,7 @@ from kpler.sdk import Platform
 from kpler.sdk.client import KplerClient
 from kpler.sdk.configuration import Configuration
 from kpler.sdk.helpers import (
+    process_bool_parameter,
     process_date_parameter,
     process_enum_parameter,
     process_enum_parameters,
@@ -63,6 +64,7 @@ class FleetDevelopmentVessels(KplerClient):
         vessel_types: Optional[List[Enum]] = None,
         gte: Optional[int] = None,
         lte: Optional[int] = None,
+        with_orderbook: bool = False,
     ):
 
         """
@@ -78,6 +80,7 @@ class FleetDevelopmentVessels(KplerClient):
             vessel_types: Optional[Enum] ``VesselTypesDry`` ``VesselTypesLNG`` ``VesselTypesLPG``
             gte: Optional[int] Get vessels with deadweight/capacity greater or equals to this value by default 0
             lte: Optional[int] Get vessels with deadweight/capacity lower or equals to this value by default 606550
+            with_orderbook: bool = False Access vessels in fleet orderbook, scheduled for future delivery
 
         Examples:
 
@@ -115,5 +118,6 @@ class FleetDevelopmentVessels(KplerClient):
             "vesselTypes": process_enum_parameters(vessel_types),
             "gte": gte,
             "lte": lte,
+            "withOrderbook": process_bool_parameter(with_orderbook),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
