@@ -16,7 +16,7 @@ from kpler.sdk.helpers import (
 class FleetUtilizationVessels(KplerClient):
 
     """
-    Access current and historical supply & demand capacity balance, total,loaded & ballast capacity evolution and capacity available by products.
+    The ``FleetUtilizationVessels`` provides current and historical supply & demand capacity balance, total,loaded & ballast capacity evolution and capacity available by products.
     """
 
     RESOURCE_NAME = "fleet-utilization/vessels"
@@ -58,19 +58,18 @@ class FleetUtilizationVessels(KplerClient):
             vessel_types: Optional[List[Enum]] ``VesselTypesDry`` ``VesselTypesLNG`` ``VesselTypesLPG``
 
         Examples:
-            >>>
-            from datetime import date
-            from kpler.sdk.resources.fleet_utilization_vessels import FleetUtilizationVessels
-            from kpler.sdk import FleetUtilizationVesselsState
-            fleet_utilization_vessels_client=FleetUtilizationVessels(config)
-            fleet_utilization_vessels_client.get(
-                start_date=date(2020,10,1),
-                end_date=date(2020,11,1),
-                zones=["Japan"],
-                products=["gasoline", "DPP"],
-                vessel_states=[FleetUtilizationVesselsState.Loaded],
-                size=5
-            )
+            >>> from datetime import date
+            ... from kpler.sdk.resources.fleet_utilization_vessels import FleetUtilizationVessels
+            ... from kpler.sdk import FleetUtilizationVesselsState
+            ... fleet_utilization_vessels_client=FleetUtilizationVessels(config)
+            ... fleet_utilization_vessels_client.get(
+            ...     start_date=date(2020,10,1),
+            ...     end_date=date(2020,11,1),
+            ...     zones=["Japan"],
+            ...     products=["gasoline", "DPP"],
+            ...    vessel_states=[FleetUtilizationVesselsState.Loaded],
+            ...     size=5
+            ... )
 
             .. csv-table::
                 :header:  "Date (timestamp)","IMO","Name","Dead Weight Tonnage","Vessel Type","Vessel State","Current Zone","Last Product on board"
